Skip to contents

Renders a forest plot showing point estimates with confidence intervals for each design, coloured by design name.

Usage

# S3 method for class 'creel_design_comparison'
autoplot(object, title = NULL, ...)

Arguments

object

A creel_design_comparison object.

title

Optional plot title.

...

Ignored.

Value

A ggplot object.