A dataset of daily ingress counts from a remote camera at a boat launch.
Contains 10 rows covering non-consecutive sampling days in June 2024.
Includes one row with camera_status = "battery_failure" and
ingress_count = NA demonstrating informative gap handling.
Format
A data frame with 10 rows and 4 variables:
- date
Survey date (Date class), non-consecutive days in June 2024.
- day_type
Day type stratum:
"weekday"or"weekend".- ingress_count
Daily ingress angler count (integer).
NAwhen the camera was not operational.- camera_status
Camera operational status. One of
"operational","battery_failure","memory_full", or"occlusion".
See also
example_camera_timestamps, example_camera_interviews,
creel_design(), add_counts()
Other "Example Datasets":
creel_counts_toy,
creel_interviews_toy,
example_aerial_counts,
example_aerial_glmm_counts,
example_aerial_interviews,
example_calendar,
example_camera_interviews,
example_camera_timestamps,
example_catch,
example_counts,
example_ice_interviews,
example_ice_sampling_frame,
example_interviews,
example_lengths,
example_sections_calendar,
example_sections_counts,
example_sections_interviews
Examples
data(example_camera_counts)
head(example_camera_counts)
#> date day_type ingress_count camera_status
#> 1 2024-06-03 weekday 48 operational
#> 2 2024-06-04 weekday 55 operational
#> 3 2024-06-05 weekday 43 operational
#> 4 2024-06-07 weekend 91 operational
#> 5 2024-06-08 weekend 85 operational
#> 6 2024-06-10 weekday 50 operational
# Filter to operational rows before adding to a camera design
data(example_calendar)
design <- creel_design(
example_calendar,
date = date, strata = day_type,
survey_type = "camera",
camera_mode = "counter"
)
counts_clean <- subset(example_camera_counts, camera_status == "operational")
design <- suppressWarnings(add_counts(design, counts_clean))