A small creel count data frame designed for demonstrating
validate_creel_data() and related data-cleaning functions. Contains
an intentional NA in the count column to trigger the NA-rate check.
Format
A data frame with 6 rows and 4 columns:
- date
Survey date (Date class).
- day_type
Day type stratum:
"weekday"or"weekend".- section
Survey section:
"A"or"B".- count
Instantaneous angler count; one row is intentionally
NA.
See also
Other "Example Datasets":
creel_interviews_toy,
example_aerial_counts,
example_aerial_glmm_counts,
example_aerial_interviews,
example_calendar,
example_camera_counts,
example_camera_interviews,
example_camera_timestamps,
example_catch,
example_counts,
example_ice_interviews,
example_ice_sampling_frame,
example_interviews,
example_lengths,
example_sections_calendar,
example_sections_counts,
example_sections_interviews
Examples
data(creel_counts_toy)
if (FALSE) { # \dontrun{
validate_creel_data(counts = creel_counts_toy)
} # }